[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- exceptions.Exception: Common base class for all exceptions.
  - nsi.granulate.GranulateOffice'.ConectionServerError
  - nsi.granulate.GranulatePDF'.ErrorXmlto
  - nsi.granulate.GranulatePDF'.PyPdf2TableError
  - exceptions.StandardError: Base class for all standard Python exceptions.
    - exceptions.AssertionError: Assertion failed.
- nsi.granulate.GranularUtils.Grain: This Class is used as reference to manipulate Grains
- object: The most base type
  - nsi.granulate.FileUtils.File: This class is used for file handling
  - nsi.granulate.Granulate'.Granulate: - Provides the content granularization delegating the responsability to the appropriate class.
  - nsi.granulate.GranulateOffice'.GranulateOffice: - Provide the grain extraction functionality for ms-office and odf documents...
  - nsi.granulate.GranulatePDF'.GranulatePDF: - Provide the grain extraction functionality for PDF documents...
  - unittest.TestCase: A class whose instances are single test cases.
    - nsi.granulate.tests.testGranulateDOC.TestGranulate
    - nsi.granulate.tests.testGranulate.TestGranulate
    - nsi.granulate.tests.testGranulateOffice.TestGranulateOffice
    - nsi.granulate.tests.testGranulatePDF.TestGranulatePDF